[][src]Struct deno::ModuleSpecifier

pub struct ModuleSpecifier(_);

Resolved module specifier

Methods

impl ModuleSpecifier[src]

pub fn to_url(&self) -> Url[src]

pub fn resolve(
    specifier: &str,
    base: &str
) -> Result<ModuleSpecifier, ModuleResolutionError>
[src]

Resolves module using this algorithm: https://html.spec.whatwg.org/multipage/webappapis.html#resolve-a-module-specifier

pub fn resolve_root(
    root_specifier: &str
) -> Result<ModuleSpecifier, ModuleResolutionError>
[src]

Takes a string representing a path or URL to a module, but of the type passed through the command-line interface for the main module. This is slightly different than specifiers used in import statements: "foo.js" for example is allowed here, whereas in import statements a leading "./" is required ("./foo.js"). This function is aware of the current working directory and returns an absolute URL.