[−][src]Struct deno::SourceCodeInfo
Represent result of fetching the source code of a module. Found module URL might be different from specified URL used for loading due to redirections (like HTTP 303). E.G. Both https://example.com/a.ts and https://example.com/b.ts may point to https://example.com/c.ts By keeping track of specified and found URL we can alias modules and avoid recompiling the same code 3 times.
Fields
code: Stringmodule_url_specified: Stringmodule_url_found: StringTrait Implementations
impl PartialEq<SourceCodeInfo> for SourceCodeInfo[src]
fn eq(&self, other: &SourceCodeInfo) -> bool[src]
fn ne(&self, other: &SourceCodeInfo) -> bool[src]
impl Eq for SourceCodeInfo[src]
impl Debug for SourceCodeInfo[src]